You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/12 08:15:32 UTC

[54/64] [abbrv] incubator-ignite git commit: Merge remote-tracking branch 'origin/master' into ignite-9469

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheStoreManager.java
----------------------------------------------------------------------
diff --cc modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStore.java
index 589187d,873b5e2..e9f6828
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStore.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStore.java
@@@ -280,12 -280,7 +280,12 @@@ public class GridCacheWriteBehindStore<
      }
  
      /** {@inheritDoc} */
 +    @Override public void configure(Object... params) {
 +        // No-op.
 +    }
 +
 +    /** {@inheritDoc} */
-     @Override public void initialize(GridKernalContext ctx) throws GridException {
+     @Override public void initialize(GridKernalContext ctx) throws IgniteCheckedException {
          if (store instanceof GridInteropAware)
              ((GridInteropAware)store).initialize(ctx);
      }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridPartitionedGetFuture.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
----------------------------------------------------------------------
diff --cc modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
index 8e1954c,144a586..4991adb
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
@@@ -12,7 -13,7 +13,8 @@@ import org.apache.ignite.*
  import org.apache.ignite.cluster.*;
  import org.apache.ignite.lang.*;
  import org.apache.ignite.plugin.security.*;
+ import org.apache.ignite.portables.*;
 +import org.gridgain.grid.*;
  import org.gridgain.grid.cache.*;
  import org.gridgain.grid.kernal.managers.communication.*;
  import org.gridgain.grid.kernal.processors.cache.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/colocated/GridDhtColocatedCache.java
----------------------------------------------------------------------
diff --cc modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/colocated/GridDhtColocatedCache.java
index 59dddd7,ae2a967..c028efd
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/colocated/GridDhtColocatedCache.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/colocated/GridDhtColocatedCache.java
@@@ -12,7 -13,7 +13,6 @@@ import org.apache.ignite.*
  import org.apache.ignite.cluster.*;
  import org.apache.ignite.lang.*;
  import org.apache.ignite.plugin.security.*;
- import org.gridgain.grid.*;
 -import org.apache.ignite.portables.*;
  import org.gridgain.grid.cache.*;
  import org.gridgain.grid.kernal.processors.cache.*;
  import org.gridgain.grid.kernal.processors.cache.distributed.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridNearGetFuture.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/interop/GridInteropAware.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/visor/VisorJob.java
----------------------------------------------------------------------
diff --cc modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheStoreManager.java
index c65ab7e,2d5aadf..f8b7623
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheStoreManager.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheStoreManager.java
@@@ -9,12 -9,11 +9,12 @@@
  
  package org.gridgain.grid.kernal.processors.cache;
  
+ import org.apache.ignite.*;
  import org.apache.ignite.lang.*;
  import org.apache.ignite.lifecycle.*;
- import org.gridgain.grid.*;
  import org.gridgain.grid.cache.*;
  import org.gridgain.grid.cache.store.*;
 +import org.gridgain.grid.kernal.processors.interop.*;
  import org.gridgain.grid.util.lang.*;
  import org.gridgain.grid.util.typedef.*;
  import org.gridgain.grid.util.typedef.internal.*;
@@@ -120,10 -103,13 +120,10 @@@ public class GridCacheStoreManager<K, V
       * @param tx Cache transaction.
       * @param key Cache key.
       * @return Loaded value, possibly <tt>null</tt>.
       * @throws GridException If data loading failed.
       */
-     @Nullable public V loadFromStore(@Nullable GridCacheTx tx, K key) throws GridException {
+     @Nullable public V loadFromStore(@Nullable GridCacheTx tx, K key) throws IgniteCheckedException {
          if (store != null) {
 -            if (log.isDebugEnabled())
 -                log.debug("Loading value from store for key: " + key);
 -
              if (key instanceof GridCacheInternal)
                  // Never load internal keys from store as they are never persisted.
                  return null;
@@@ -182,8 -162,11 +182,8 @@@
       */
      @SuppressWarnings({"unchecked"})
      public boolean loadAllFromStore(@Nullable GridCacheTx tx, Collection<? extends K> keys,
-         final IgniteBiInClosure<K, V> vis) throws GridException {
+         final IgniteBiInClosure<K, V> vis) throws IgniteCheckedException {
          if (store != null) {
 -            if (log.isDebugEnabled())
 -                log.debug("Loading values from store for keys: " + keys);
 -
              if (!keys.isEmpty()) {
                  if (keys.size() == 1) {
                      K key = F.first(keys);
@@@ -223,13 -186,13 +223,13 @@@
                  catch (ClassCastException e) {
                      handleClassCastException(e);
                  }
-                 catch (GridRuntimeException e) {
+                 catch (IgniteException e) {
                      throw U.cast(e);
                  }
 -            }
  
 -            if (log.isDebugEnabled())
 -                log.debug("Loaded values from store for keys: " + keys);
 +                if (log.isDebugEnabled())
 +                    log.debug("Loaded values from store for keys: " + keys0);
 +            }
  
              return true;
          }
@@@ -297,20 -260,11 +297,20 @@@
       * @param val Value.
       * @param ver Version.
       * @return {@code true} If there is a persistent storage.
       * @throws GridException If storage failed.
       */
      public boolean putToStore(@Nullable GridCacheTx tx, K key, V val, GridCacheVersion ver)
-         throws GridException {
+         throws IgniteCheckedException {
          if (store != null) {
 +            // Never persist internal keys.
 +            if (key instanceof GridCacheInternal)
 +                return true;
 +
 +            if (convertPortable) {
 +                key = (K)cctx.unwrapPortableIfNeeded(key, false);
 +                val = (V)cctx.unwrapPortableIfNeeded(val, false);
 +            }
 +
              if (log.isDebugEnabled())
                  log.debug("Storing value in cache store [key=" + key + ", val=" + val + ']');
  
@@@ -336,10 -296,10 +336,10 @@@
       * @param tx Cache transaction.
       * @param map Map.
       * @return {@code True} if there is a persistent storage.
       * @throws GridException If storage failed.
       */
 -    public boolean putAllToStore(@Nullable GridCacheTx tx,
 -        Map<K, IgniteBiTuple<V, GridCacheVersion>> map) throws IgniteCheckedException {
 +    public boolean putAllToStore(@Nullable GridCacheTx tx, Map<K, IgniteBiTuple<V, GridCacheVersion>> map)
-         throws GridException {
++        throws IgniteCheckedException {
          if (F.isEmpty(map))
              return true;
  
@@@ -394,17 -339,10 +394,17 @@@
       * @param tx Cache transaction.
       * @param key Key.
       * @return {@code True} if there is a persistent storage.
       * @throws GridException If storage failed.
       */
-     public boolean removeFromStore(@Nullable GridCacheTx tx, K key) throws GridException {
+     public boolean removeFromStore(@Nullable GridCacheTx tx, K key) throws IgniteCheckedException {
          if (store != null) {
 +            // Never remove internal key from store as it is never persisted.
 +            if (key instanceof GridCacheInternal)
 +                return false;
 +
 +            if (convertPortable)
 +                key = (K)cctx.unwrapPortableIfNeeded(key, false);
 +
              if (log.isDebugEnabled())
                  log.debug("Removing value from cache store [key=" + key + ']');
  

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/73528bb4/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStore.java
----------------------------------------------------------------------
@@@ -120,10 -103,13 +120,10 @@@ public class GridCacheStoreManager<K, V
       * @param key Cache key.
       * @return Loaded value, possibly <tt>null</tt>.
-      * @throws GridException If data loading failed.
+      * @throws IgniteCheckedException If data loading failed.
       */
@@@ -297,20 -260,11 +297,20 @@@
       * @param ver Version.
       * @return {@code true} If there is a persistent storage.
-      * @throws GridException If storage failed.
+      * @throws IgniteCheckedException If storage failed.
       */
      public boolean putToStore(@Nullable GridCacheTx tx, K key, V val, GridCacheVersion ver)
@@@ -336,10 -296,10 +336,10 @@@
       * @param map Map.
       * @return {@code True} if there is a persistent storage.
-      * @throws GridException If storage failed.
+      * @throws IgniteCheckedException If storage failed.
       */
 -    public boolean putAllToStore(@Nullable GridCacheTx tx,
@@@ -394,17 -339,10 +394,17 @@@
       * @param key Key.
       * @return {@code True} if there is a persistent storage.
-      * @throws GridException If storage failed.
+      * @throws IgniteCheckedException If storage failed.
       */